"use strict";
/**
 * Utils - Get Json
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getJsonFile = exports.getJson = void 0;
/* Imports */
const isObject_1 = require("../isObject/isObject");
const getPath_1 = require("../getPath/getPath");
const filters_1 = require("../filters/filters");
/**
 * Function - check and return valid JSON or fallback
 *
 * @param {string} value
 * @return {object|undefined}
 */
const getJson = (value) => {
    try {
        const obj = JSON.parse(value);
        if ((0, isObject_1.isObject)(obj)) {
            return obj;
        }
    }
    catch {
        return undefined;
    }
    return undefined;
};
exports.getJson = getJson;
/**
 * Function - import json file and return contents if object
 *
 * @param {string} path
 * @param {boolean} store
 * @return {Promise<object|undefined>}
 */
const getJsonFile = async (path, store = true) => {
    try {
        const newPath = store ? (0, getPath_1.getPath)(path, 'store') : path;
        const { default: obj } = await Promise.resolve(`${newPath}`).then(s => require(s)); // Removed assert json as not all exports are esnext
        if ((0, isObject_1.isObject)(obj)) {
            return obj;
        }
        throw new Error('No object in json file');
    }
    catch {
        if (!store) {
            return undefined;
        }
        return await (0, filters_1.applyFilters)('storeData', undefined, path);
    }
};
exports.getJsonFile = getJsonFile;
